@@ -3,12 +3,11 @@
 #             All rights reserved.
 # :license:   BSD (3 Clause), see LICENSE for more details.
 import re
-
 from collections import namedtuple
 
 import django
 
-__version__ = '2.2.1'
+__version__ = '2.4.0'
 __author__ = 'Asif Saif Uddin, Ask Solem'
 __contact__ = 'auvipy@gmail.com, ask@celeryproject.org'
 __homepage__ = 'https://github.com/celery/django-celery-beat'
@@ -26,8 +25,8 @@ _temp = re.match(
     r'(\d+)\.(\d+).(\d+)(.+)?', __version__).groups()
 VERSION = version_info = version_info_t(
     int(_temp[0]), int(_temp[1]), int(_temp[2]), _temp[3] or '', '')
-del(_temp)
-del(re)
+del _temp
+del re
 
 __all__ = []
 
