@@ -3,22 +3,21 @@ try:
     from zoneinfo import available_timezones
 except ImportError:
     from backports.zoneinfo import available_timezones
+
 from datetime import timedelta
 
 import timezone_field
-from celery import schedules, current_app
+from celery import current_app, schedules
 from django.conf import settings
 from django.core.exceptions import MultipleObjectsReturned, ValidationError
 from django.core.validators import MaxValueValidator, MinValueValidator
 from django.db import models
-from django.db.models import signals
 from django.utils.translation import gettext_lazy as _
 
-from . import managers, validators
+from . import querysets, validators
+from .clockedschedule import clocked
 from .tzcrontab import TzAwareCrontab
 from .utils import make_aware, now
-from .clockedschedule import clocked
-
 
 DAYS = 'days'
 HOURS = 'hours'
@@ -64,7 +63,7 @@ def crontab_schedule_celery_timezone():
     """Return timezone string from Django settings ``CELERY_TIMEZONE`` variable.
 
     If is not defined or is not a valid timezone, return ``"UTC"`` instead.
-    """
+    """  # noqa: E501
     try:
         CELERY_TIMEZONE = getattr(
             settings, '%s_TIMEZONE' % current_app.namespace)
@@ -130,7 +129,7 @@ class SolarSchedule(models.Model):
             return cls(**spec)
 
     def __str__(self):
-        return '{0} ({1}, {2})'.format(
+        return '{} ({}, {})'.format(
             self.get_event_display(),
             self.latitude,
             self.longitude
@@ -225,7 +224,7 @@ class ClockedSchedule(models.Model):
         ordering = ['clocked_time']
 
     def __str__(self):
-        return '{}'.format(make_aware(self.clocked_time))
+        return f'{make_aware(self.clocked_time)}'
 
     @property
     def schedule(self):
@@ -315,7 +314,7 @@ class CrontabSchedule(models.Model):
                     'day_of_week', 'hour', 'minute', 'timezone']
 
     def __str__(self):
-        return '{0} {1} {2} {3} {4} (m/h/dM/MY/d) {5}'.format(
+        return '{} {} {} {} {} (m/h/dM/MY/d) {}'.format(
             cronexp(self.minute), cronexp(self.hour),
             cronexp(self.day_of_month), cronexp(self.month_of_year),
             cronexp(self.day_of_week), str(self.timezone)
@@ -370,8 +369,6 @@ class PeriodicTasks(models.Model):
     ident = models.SmallIntegerField(default=1, primary_key=True, unique=True)
     last_update = models.DateTimeField(null=False)
 
-    objects = managers.ExtendedManager()
-
     @classmethod
     def changed(cls, instance, **kwargs):
         if not instance.no_changes:
@@ -541,7 +538,7 @@ class PeriodicTask(models.Model):
             'Detailed description about the details of this Periodic Task'),
     )
 
-    objects = managers.PeriodicTaskManager()
+    objects = querysets.PeriodicTaskQuerySet.as_manager()
     no_changes = False
 
     class Meta:
@@ -586,6 +583,11 @@ class PeriodicTask(models.Model):
         self._clean_expires()
         self.validate_unique()
         super().save(*args, **kwargs)
+        PeriodicTasks.changed(self)
+
+    def delete(self, *args, **kwargs):
+        super().delete(*args, **kwargs)
+        PeriodicTasks.changed(self)
 
     def _clean_expires(self):
         if self.expire_seconds is not None and self.expires:
@@ -619,23 +621,3 @@ class PeriodicTask(models.Model):
             return self.solar.schedule
         if self.clocked:
             return self.clocked.schedule
-
-
-signals.pre_delete.connect(PeriodicTasks.changed, sender=PeriodicTask)
-signals.pre_save.connect(PeriodicTasks.changed, sender=PeriodicTask)
-signals.pre_delete.connect(
-    PeriodicTasks.update_changed, sender=IntervalSchedule)
-signals.post_save.connect(
-    PeriodicTasks.update_changed, sender=IntervalSchedule)
-signals.post_delete.connect(
-    PeriodicTasks.update_changed, sender=CrontabSchedule)
-signals.post_save.connect(
-    PeriodicTasks.update_changed, sender=CrontabSchedule)
-signals.post_delete.connect(
-    PeriodicTasks.update_changed, sender=SolarSchedule)
-signals.post_save.connect(
-    PeriodicTasks.update_changed, sender=SolarSchedule)
-signals.post_delete.connect(
-    PeriodicTasks.update_changed, sender=ClockedSchedule)
-signals.post_save.connect(
-    PeriodicTasks.update_changed, sender=ClockedSchedule)
